==> selenium-remote-driver-4.0.0-rc-2-sources.jar: org/openqa/selenium/remote/tracing/EventAttribute.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote.tracing;

public class EventAttribute {

  private EventAttribute() {
  }

  public static EventAttributeValue setValue(String value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(boolean value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(long value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(String... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(long... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(double... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(boolean... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(double value) {
    return new EventAttributeValue(value);
  }
}

==> selenium-remote-driver-4.12.0-sources.jar: org/openqa/selenium/remote/tracing/EventAttribute.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote.tracing;

public class EventAttribute {

  private EventAttribute() {}

  public static EventAttributeValue setValue(String value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(boolean value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(long value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(String... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(long... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(double... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(boolean... value) {
    return new EventAttributeValue(value);
  }

  public static EventAttributeValue setValue(double value) {
    return new EventAttributeValue(value);
  }
}
